import"./jwt-decode.esm-B3xaLXnJ.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="863e85f6-aa7b-4863-8838-6afd43239262",x._sentryDebugIdIdentifier="sentry-dbid-863e85f6-aa7b-4863-8838-6afd43239262")}catch{}})();const d=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{d as u};
//# sourceMappingURL=uuid-CgT0UdkA.js.map
