import{C as p,_ as n}from"./View.vue_vue_type_script_setup_true_lang-CElrjKQm.js";import{a as i,ac as s,p as a,e as m,u as c}from"./jwt-decode.esm-B3xaLXnJ.js";import"./router-Dn_c-BTv.js";import"./ts.worker-BL4rR3aW.js";import"./fetch-CW2dq1bB.js";import"./record-DPNS9Nu2.js";import"./SaveButton-Bfal4vfe.js";import"./ExclamationCircleOutlined-CtJNf_Fd.js";import"./CrudView-Dntygqr3.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-DuZ2wl9F.js";import"./constants-4lbqwSCn.js";import"./url-CITwN0hp.js";import"./PhDotsThreeVertical.vue-Ce2qBZr8.js";import"./index-ieYAUmih.js";import"./asyncComputed-BoEoWUyl.js";import"./omniChatStore-S3jQRCWp.js";import"./uuid-CgT0UdkA.js";import"./PhCopySimple.vue-cgX_Lb99.js";import"./PhPencil.vue-D3zBH1es.js";import"./useCodebaseEvents-B2oV4HZ2.js";import"./contracts.generated-83ElrmM1.js";import"./index-86UpjsGy.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="230ca48c-a644-4640-8542-45412115e5ee",o._sentryDebugIdIdentifier="sentry-dbid-230ca48c-a644-4640-8542-45412115e5ee")}catch{}})();const A=i({__name:"EnvVars",setup(o){const r=s().params.projectId,t=new p(r);return(d,u)=>(m(),a(n,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-DlAVeHIl.js.map
