import{aR as r,aS as n,a5 as o,aT as c,aU as d,aV as p,aW as b,aX as f,aY as m,aZ as s,a_ as u,a$ as g,b0 as l}from"./jwt-decode.esm-B3xaLXnJ.js";import{g as y,r as i}from"./router-BLgAPxNp.js";import{s as w}from"./workspaceStore-D72mWFRj.js";import{_}from"./App.vue_vue_type_style_index_0_lang-BIGRahG2.js";import"./userStore-Do2fHKvI.js";import"./url-CITwN0hp.js";import"./colorHelpers-CJp3gMpO.js";import"./PlayerConfigProvider-CGEDaVuY.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="a5a338cf-62e0-4d44-9b29-fbc91b1b0c0b",t._sentryDebugIdIdentifier="sentry-dbid-a5a338cf-62e0-4d44-9b29-fbc91b1b0c0b")}catch{}})();class h{static init(){setInterval(()=>{fetch("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await y(),a=r(),e=n({render:()=>o(_)});c.init(),d(e,i,t),h.init(),e.use(i),e.use(a),e.use(p),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",f),e.component("Message",m),s(e,u),s(e,g),s(e,l)})();
//# sourceMappingURL=player-CqFpTl0O.js.map
