const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-CkK3YhOo.js","assets/workspaceStore-D72mWFRj.js","assets/jwt-decode.esm-B3xaLXnJ.js","assets/jwt-decode-D9e-DIPp.css","assets/userStore-Do2fHKvI.js","assets/url-CITwN0hp.js","assets/colorHelpers-CJp3gMpO.js","assets/OidcLogoutCallback-DxC2UA0U.js","assets/Login-maHysSTy.js","assets/Login.vue_vue_type_script_setup_true_lang-CrmD_m4X.js","assets/OTPInput-DN5Bvn0e.js","assets/OTPInput-C8ldH5jb.css","assets/Logo-CmDYEj1O.js","assets/Logo-D2kepPyK.css","assets/string-DogBIB0c.js","assets/CircularLoading-CFZs4QUT.js","assets/CircularLoading-BiyobKo3.css","assets/index-86UpjsGy.js","assets/Login-cMuNqCbG.css","assets/Login-C1k-SC0u.css","assets/Main-DenTcxyN.js","assets/PlayerNavbar-DAJjJWG3.js","assets/metadata-CrtcW0vq.js","assets/PhMagnifyingGlass.vue-HjPECC7e.js","assets/PhWebhooksLogo.vue-b9SH8jfK.js","assets/LoadingOutlined-DwXRrirm.js","assets/PhSignOut.vue-BIcnu4Vw.js","assets/index-BDwDBCkK.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-DJJxhnDs.js","assets/Watermark-B4tP1y0h.js","assets/constants-4lbqwSCn.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-E-WKNNnU.js","assets/index-Bz1l1FQ3.js","assets/Home-B6UGln4L.css","assets/Error-CIfuKSHX.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-Datielov.js","assets/Error-CIbhyrKS.css","assets/Form-D-4S6VrO.js","assets/FormRunner-1At6XeGR.js","assets/Steps-CDRT5dQ1.js","assets/index-BVZzXD-s.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-61-wByB6.css","assets/redirect-Bt4PQbHo.js","assets/asyncComputed-BoEoWUyl.js","assets/uuid-CgT0UdkA.js","assets/Form-A1oa-Q46.css"])))=>i.map(i=>d[i]);
import{ag as s,ah as d,ad as t,ai as m}from"./jwt-decode.esm-B3xaLXnJ.js";import{a as u}from"./workspaceStore-D72mWFRj.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="da8eb0bc-a42b-42b0-921d-13fdbb1413d3",e._sentryDebugIdIdentifier="sentry-dbid-da8eb0bc-a42b-42b0-921d-13fdbb1413d3")}catch{}})();const f=async()=>{try{const e=await fetch("/_editor/api/workspace/version");return e.ok&&(await e.json()).version||"e24c5a2c7c8c45f98c9035b1b0fcd9ffc4e1708c"}catch(e){return console.error("Failed to fetch Abstra version:",e),"e24c5a2c7c8c45f98c9035b1b0fcd9ffc4e1708c"}},p=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-CkK3YhOo.js"),__vite__mapDeps([0,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-DxC2UA0U.js"),__vite__mapDeps([7,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-maHysSTy.js"),__vite__mapDeps([8,9,2,3,1,4,5,6,10,11,12,13,14,15,16,17,18,19])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-DenTcxyN.js"),__vite__mapDeps([20,21,4,2,3,1,5,6,22,23,24,25,26,27,28,29])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-DJJxhnDs.js"),__vite__mapDeps([30,22,2,3,23,24,31,1,4,5,6,32,33,34,35,25,36])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-CIfuKSHX.js"),__vite__mapDeps([37,38,12,2,3,13,32,1,4,5,6,35,39])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-D-4S6VrO.js"),__vite__mapDeps([40,4,2,3,41,9,1,5,6,10,11,12,13,14,15,16,17,18,42,43,44,31,32,33,45,46,47,48,49])),meta:{hideLogin:!0}}]}],o=s({history:d("/"),routes:p,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),l=e=>async(a,r)=>{if(m(a,r),a.meta.allowUnauthenticated)return;const c=await u(a.path),{redirect:n,...i}=a.query;switch(c.status){case"ALLOWED":break;case"UNAUTHORIZED":await e.push({name:"playerLogin",query:{...i,redirect:n||a.path},params:a.params});break;case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};o.beforeEach(l(o));export{p as a,l as b,f as g,o as r};
//# sourceMappingURL=router-BLgAPxNp.js.map
