import{j as o,I as d,aa as u}from"./jwt-decode.esm-B3xaLXnJ.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="04ca1153-e8e3-45bf-af84-2ac41e0518fd",e._sentryDebugIdIdentifier="sentry-dbid-04ca1153-e8e3-45bf-af84-2ac41e0518fd")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){c(e,a,n[a])})}return e}function c(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var f=function(t,n){var r=i({},t,n.attrs);return o(d,i({},r,{icon:u}),null)};f.displayName="LoadingOutlined";f.inheritAttrs=!1;export{f as L};
//# sourceMappingURL=LoadingOutlined-DwXRrirm.js.map
